## List of packages exported from working environment
## - pinned versions were obtained from
## https://github.com/csoneson/orthos_package_list

if (basilisk::isLinuxAarch64()) {
    .orthos_dependencies <- c(
        "python==3.12",
        "absl-py==2.3.1",
        "astunparse==1.6.3",
        "certifi==2025.8.3",
        "charset-normalizer==3.4.3",
        "flatbuffers==25.2.10",
        "gast==0.6.0",
        "google-pasta==0.2.0",
        "grpcio==1.74.0",
        "h5py==3.14.0",
        "idna==3.10",
        "keras==3.11.3",
        "libclang==18.1.1",
        "Markdown==3.8.2",
        "markdown-it-py==4.0.0",
        "MarkupSafe==3.0.2",
        "mdurl==0.1.2",
        "ml_dtypes==0.5.3",
        "namex==0.1.0",
        "numpy==1.26.4",
        "opt_einsum==3.4.0",
        "optree==0.17.0",
        "packaging==25.0",
        "pandas==2.3.2",
        "pillow==11.3.0",
        "pip==25.2",
        "protobuf==5.29.5",
        "Pygments==2.19.2",
        "python-dateutil==2.9.0.post0",
        "pytz==2025.2",
        "requests==2.32.5",
        "rich==14.1.0",
        "setuptools==80.9.0",
        "six==1.17.0",
        "tensorboard==2.19.0",
        "tensorboard-data-server==0.7.2",
        "tensorflow==2.19.0",
        "termcolor==3.1.0",
        "tf-keras==2.19.0",
        "typing_extensions==4.15.0",
        "tzdata==2025.2",
        "urllib3==2.5.0",
        "Werkzeug==3.1.3",
        "wheel==0.45.1",
        "wrapt==1.17.3"
    )
} else if (basilisk::isLinux()) {
    .orthos_dependencies <- c(
        "python==3.12",
        "absl-py==2.3.1",
        "astunparse==1.6.3",
        "certifi==2025.8.3",
        "charset-normalizer==3.4.3",
        "flatbuffers==25.2.10",
        "gast==0.6.0",
        "google-pasta==0.2.0",
        "grpcio==1.74.0",
        "h5py==3.14.0",
        "idna==3.10",
        "keras==3.11.3",
        "libclang==18.1.1",
        "Markdown==3.8.2",
        "markdown-it-py==4.0.0",
        "MarkupSafe==3.0.2",
        "mdurl==0.1.2",
        "ml_dtypes==0.5.3",
        "namex==0.1.0",
        "numpy==1.26.4",
        "opt_einsum==3.4.0",
        "optree==0.17.0",
        "packaging==25.0",
        "pandas==2.3.2",
        "pillow==11.3.0",
        "pip==25.2",
        "protobuf==5.29.5",
        "Pygments==2.19.2",
        "python-dateutil==2.9.0.post0",
        "pytz==2025.2",
        "requests==2.32.5",
        "rich==14.1.0",
        "setuptools==80.9.0",
        "six==1.17.0",
        "tensorboard==2.19.0",
        "tensorboard-data-server==0.7.2",
        "tensorflow==2.19.0",
        "termcolor==3.1.0",
        "tf-keras==2.19.0",
        "typing_extensions==4.15.0",
        "tzdata==2025.2",
        "urllib3==2.5.0",
        "Werkzeug==3.1.3",
        "wheel==0.45.1",
        "wrapt==1.17.3"
    )
} else if (basilisk::isMacOSXArm()) {
    .orthos_dependencies <- c(
        "python==3.12",
        "absl-py==2.3.1",
        "astunparse==1.6.3",
        "certifi==2025.8.3",
        "charset-normalizer==3.4.3",
        "flatbuffers==25.2.10",
        "gast==0.6.0",
        "google-pasta==0.2.0",
        "grpcio==1.74.0",
        "h5py==3.14.0",
        "idna==3.10",
        "keras==3.11.3",
        "libclang==18.1.1",
        "Markdown==3.8.2",
        "markdown-it-py==4.0.0",
        "MarkupSafe==3.0.2",
        "mdurl==0.1.2",
        "ml_dtypes==0.5.3",
        "namex==0.1.0",
        "numpy==1.26.4",
        "opt_einsum==3.4.0",
        "optree==0.17.0",
        "packaging==25.0",
        "pandas==2.3.2",
        "pillow==11.3.0",
        "pip==25.2",
        "protobuf==5.29.5",
        "Pygments==2.19.2",
        "python-dateutil==2.9.0.post0",
        "pytz==2025.2",
        "requests==2.32.5",
        "rich==14.1.0",
        "setuptools==80.9.0",
        "six==1.17.0",
        "tensorboard==2.19.0",
        "tensorboard-data-server==0.7.2",
        "tensorflow==2.19.0",
        "termcolor==3.1.0",
        "tf-keras==2.19.0",
        "typing_extensions==4.15.0",
        "tzdata==2025.2",
        "urllib3==2.5.0",
        "Werkzeug==3.1.3",
        "wheel==0.45.1",
        "wrapt==1.17.3"
    )
} else if (basilisk::isMacOSX()) {
    .orthos_dependencies <- c(
        "python==3.12",
        "absl-py==2.3.1",
        "astunparse==1.6.3",
        "certifi==2025.8.3",
        "charset-normalizer==3.4.3",
        "flatbuffers==25.2.10",
        "gast==0.6.0",
        "google-pasta==0.2.0",
        "grpcio==1.74.0",
        "h5py==3.14.0",
        "idna==3.10",
        "keras==3.11.3",
        "libclang==18.1.1",
        "Markdown==3.8.2",
        "markdown-it-py==4.0.0",
        "MarkupSafe==3.0.2",
        "mdurl==0.1.2",
        "ml_dtypes==0.3.2",
        "namex==0.1.0",
        "numpy==1.26.4",
        "opt_einsum==3.4.0",
        "optree==0.17.0",
        "packaging==25.0",
        "pandas==2.3.2",
        "pillow==11.3.0",
        "pip==25.2",
        "protobuf==4.25.8",
        "Pygments==2.19.2",
        "python-dateutil==2.9.0.post0",
        "pytz==2025.2",
        "requests==2.32.5",
        "rich==14.1.0",
        "setuptools==80.9.0",
        "six==1.17.0",
        "tensorboard==2.16.2",
        "tensorboard-data-server==0.7.2",
        "tensorflow==2.16.2",
        "termcolor==3.1.0",
        "tf-keras==2.16.0",
        "typing_extensions==4.15.0",
        "tzdata==2025.2",
        "urllib3==2.5.0",
        "Werkzeug==3.1.3",
        "wheel==0.45.1",
        "wrapt==1.17.3"
    )
} else if (basilisk::isWindows()) {
    .orthos_dependencies <- c(
        "python==3.12",
        "absl-py==2.3.1",
        "astunparse==1.6.3",
        "certifi==2025.8.3",
        "charset-normalizer==3.4.3",
        "flatbuffers==25.2.10",
        "gast==0.6.0",
        "google-pasta==0.2.0",
        "grpcio==1.74.0",
        "h5py==3.14.0",
        "idna==3.10",
        "keras==3.11.3",
        "libclang==18.1.1",
        "Markdown==3.8.2",
        "markdown-it-py==4.0.0",
        "MarkupSafe==3.0.2",
        "mdurl==0.1.2",
        "ml_dtypes==0.5.3",
        "namex==0.1.0",
        "numpy==1.26.4",
        "opt_einsum==3.4.0",
        "optree==0.17.0",
        "packaging==25.0",
        "pandas==2.3.2",
        "pillow==11.3.0",
        "pip==25.2",
        "protobuf==5.29.5",
        "Pygments==2.19.2",
        "python-dateutil==2.9.0.post0",
        "pytz==2025.2",
        "requests==2.32.5",
        "rich==14.1.0",
        "setuptools==80.9.0",
        "six==1.17.0",
        "tensorboard==2.19.0",
        "tensorboard-data-server==0.7.2",
        "tensorflow==2.19.0",
        "termcolor==3.1.0",
        "tf-keras==2.19.0",
        "typing_extensions==4.15.0",
        "tzdata==2025.2",
        "urllib3==2.5.0",
        "Werkzeug==3.1.3",
        "wheel==0.45.1",
        "wrapt==1.17.3"
    )
}

#' @author Charlotte Soneson
#'
#' @importFrom basilisk BasiliskEnvironment
orthosenv <- basilisk::BasiliskEnvironment(
    envname = "orthos", pkgname = "orthos",
    packages = .orthos_dependencies
)
